diff --git a/mutalyzer/Scheduler.py b/mutalyzer/Scheduler.py
index a9703c4ae50a5fe18199122526a71f4bc3bb98d5..d54ec427af0bbd096fbe9ad9ce05bdb3b21bafd7 100644
--- a/mutalyzer/Scheduler.py
+++ b/mutalyzer/Scheduler.py
@@ -476,7 +476,7 @@ Mutalyzer batch checker.""" % url)
     def _processConversion(self, cmd, i, build, flags) :
         """
         Process an entry from the Position Converter, write the results
         to the job-file. The Position Coverter is wrapped in a try except
         block which ensures that he Batch Process keeps running. Errors
         are caught and the user will be notified.
 
@@ -501,7 +501,7 @@ Mutalyzer batch checker.""" % url)
         cNames = [""]
 
         O.addMessage(__file__, -1, "INFO",
-            "Received PositionCoverter batchvariant " + cmd)
+            "Received PositionConverter batchvariant " + cmd)
 
         skip = self.__processFlags(O, flags)
         if not skip :
@@ -572,7 +572,7 @@ Mutalyzer batch checker.""" % url)
         handle.write("%s\t%s\t%s\t%s%s" % (cmd, error, gName, "\t".join(cNames), separator))
         handle.close()
         O.addMessage(__file__, -1, "INFO",
-            "Finisehd PositionCoverter batchvariant " + cmd)
+            "Finisehd PositionConverter batchvariant " + cmd)
     #_processConversion
@@ -476,7 +476,7 @@ Mutalyzer batch checker.""" % url)
         """
         Process an entry from the Position Converter, write the results
-        to the job-file. The Position Coverter is wrapped in a try except
+        to the job-file. The Position Converter is wrapped in a try except
         block which ensures that he Batch Process keeps running. Errors
         are caught and the user will be notified.